#[non_exhaustive]pub enum UiError {
NotImplemented,
NotSupported,
Io(IoError),
}Available on
ui·· only.Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotImplemented
The requested numerical functionality is not implemented.
This is the default implementation of every numeric trait method.
NotSupported
The requested functionality is not supported by this number type.
Io(IoError)
Available on crate feature
sys only.An io error.